==> tuia-commercial-center-api-1.1.16-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/farm/FarmConfigDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.farm;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * FarmConfigDto
 *
 * @author huangruodan
 * @date 2020-01-20
 */

@Data
public class FarmConfigDto implements Serializable {

    private static final long serialVersionUID = 1714411167077557428L;
    /**
     * 成就列表
     */
    private List<FarmAchievementConfigDto> achievementConfigList;

    /**
     * 设施配置列表
     */
    private List<FarmFacilityConfigDto> facilityConfigList;


    /**
     * 财务模型配置列表
     */
    private List<FarmFinanceVersionConfigDto> financeConfigList;

    /**
     * 果实配置列表
     */
    private List<FarmFruitConfigDto> fruitConfigList;

    /**
     * 功能配置列表
     */
    private List<FarmFunctionConfigDto> functionConfigList;

    /**
     * 任务列表
     */
    private List<FarmMissionConfigDto> missionConfigList;

    /**
     * 神秘客配置
     */
    private List<FarmMysteriousGuestConfigDto> mysteriousGuestConfigList;

    /**
     * 离线收益配置
     */
    private List<FarmOfflineConfigDto> offlineConfigList;

    /**
     * 随机事件配置
     */
    private List<FarmRandomEventConfigDto> randomEventConfigList;

    /**
     * 签到配置
     */
    private List<FarmSignConfigDto> signConfigList;

    /**
     * 解锁土地配置
     */
    private List<FarmUnlockLandConfigDto> unlockLandConfigList;

    /**
     * 浇水配置
     */
    private List<FarmWaterConfigVersionDto> waterConfigList;

    /**
     * 图鉴配置
     */
    private List<FarmPropConfigDto> propConfigList;

    /**
     *
     */
    private List<FarmBeginGiftConfigDto> beginGiftList;

    /**
     * 激励视频活动配置
     */
    private List<FarmRewardVideoConfigDto> rewardVideoConfigList;
}

==> tuia-commercial-center-api-1.1.35-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/farm/FarmConfigDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.farm;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * FarmConfigDto
 *
 * @author huangruodan
 * @date 2020-01-20
 */

@Data
public class FarmConfigDto implements Serializable {

    private static final long serialVersionUID = 1714411167077557428L;
    /**
     * 成就列表
     */
    private List<FarmAchievementConfigDto> achievementConfigList;

    /**
     * 设施配置列表
     */
    private List<FarmFacilityConfigDto> facilityConfigList;


    /**
     * 财务模型配置列表
     */
    private List<FarmFinanceVersionConfigDto> financeConfigList;

    /**
     * 果实配置列表
     */
    private List<FarmFruitConfigDto> fruitConfigList;

    /**
     * 功能配置列表
     */
    private List<FarmFunctionConfigDto> functionConfigList;

    /**
     * 任务列表
     */
    private List<FarmMissionConfigDto> missionConfigList;

    /**
     * 神秘客配置
     */
    private List<FarmMysteriousGuestConfigDto> mysteriousGuestConfigList;

    /**
     * 离线收益配置
     */
    private List<FarmOfflineConfigDto> offlineConfigList;

    /**
     * 随机事件配置
     */
    private List<FarmRandomEventConfigDto> randomEventConfigList;

    /**
     * 签到配置
     */
    private List<FarmSignConfigDto> signConfigList;

    /**
     * 解锁土地配置
     */
    private List<FarmUnlockLandConfigDto> unlockLandConfigList;

    /**
     * 浇水配置
     */
    private List<FarmWaterConfigVersionDto> waterConfigList;

    /**
     * 图鉴配置
     */
    private List<FarmPropConfigDto> propConfigList;

    /**
     *
     */
    private List<FarmBeginGiftConfigDto> beginGiftList;

    /**
     * 激励视频活动配置
     */
    private List<FarmRewardVideoConfigDto> rewardVideoConfigList;


    /**
     * 贡献任务配置
     */
    private List<FarmContributionMissionDto> contributionMissionDtos;


    /**
     * 贡献任务配置
     */
    private List<FarmLevelConfigDto> farmLevelConfigDtos;


    /**
     * 贡献任务配置
     */
    private List<FarmLotteryConfigDto> farmLotteryConfigDtos;
}
